==> uniq-1.2.0.25-py3-none-any.whl: uniq/apis/nb/clients/task_service_client/models/AugmentedAuditResourceDTO.py <==
#!/usr/bin/env python
#pylint: skip-file
"""
Copyright 2016 Cisco Systems

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

class AugmentedAuditResourceDTO(object):



    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {

            'instanceUuid': 'str',


            'tag': 'str',


            'hasParent': 'bool',


            'createdDateTime': 'date-time',


            'auditId': 'str',


            'auditParentId': 'str',


            'auditRequestor': 'str',


            'auditDescription': 'str',


            'derivedParentId': 'str',


            'deviceIP': 'str',


            'deviceName': 'str',


            'siteName': 'str',


            'hasChildren': 'bool',


            'auditParameters': 'str',


            'persistDateTime': 'date-time',


            'state': 'str'

        }

        self.attributeMap = {

            'instanceUuid': 'instanceUuid',

            'tag': 'tag',

            'hasParent': 'hasParent',

            'createdDateTime': 'createdDateTime',

            'auditId': 'auditId',

            'auditParentId': 'auditParentId',

            'auditRequestor': 'auditRequestor',

            'auditDescription': 'auditDescription',

            'derivedParentId': 'derivedParentId',

            'deviceIP': 'deviceIP',

            'deviceName': 'deviceName',

            'siteName': 'siteName',

            'hasChildren': 'hasChildren',

            'auditParameters': 'auditParameters',

            'persistDateTime': 'persistDateTime',

            'state': 'state'

        }


        #This field is deprecated. Use &#39;id&#39; instead.

        self.instanceUuid = None # str


        self.tag = None # str


        self.hasParent = None # bool


        self.createdDateTime = None # date-time


        self.auditId = None # str


        self.auditParentId = None # str


        self.auditRequestor = None # str


        self.auditDescription = None # str


        self.derivedParentId = None # str


        self.deviceIP = None # str


        self.deviceName = None # str


        self.siteName = None # str


        self.hasChildren = None # bool


        self.auditParameters = None # str


        self.persistDateTime = None # date-time


        self.state = None # str

==> uniq-1.4.0.36-py3-none-any.whl: uniq/apis/nb/clients/task_service_client/models/AugmentedAuditResourceDTO.py <==
#!/usr/bin/env python
#pylint: skip-file
# This source code is licensed under the Apache license found in the
# LICENSE file in the root directory of this project.


class AugmentedAuditResourceDTO(object):


    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {
            
            'instanceUuid': 'str',
            
            
            'severity': 'str',
            
            
            'tag': 'str',
            
            
            'applicationName': 'str',
            
            
            'auditParameters': 'dict',
            
            
            'deviceIP': 'str',
            
            
            'auditDescription': 'str',
            
            
            'auditRequestor': 'str',
            
            
            'createdDateTime': 'date-time',
            
            
            'derivedParentId': 'str',
            
            
            'deviceName': 'str',
            
            
            'hasChildren': 'bool',
            
            
            'hasParent': 'bool',
            
            
            'persistDateTime': 'date-time',
            
            
            'siteName': 'str',
            
            
            'auditParentId': 'str',
            
            
            'auditId': 'str'
            
        }

        self.attributeMap = {
            
            'instanceUuid': 'instanceUuid',
            
            'severity': 'severity',
            
            'tag': 'tag',
            
            'applicationName': 'applicationName',
            
            'auditParameters': 'auditParameters',
            
            'deviceIP': 'deviceIP',
            
            'auditDescription': 'auditDescription',
            
            'auditRequestor': 'auditRequestor',
            
            'createdDateTime': 'createdDateTime',
            
            'derivedParentId': 'derivedParentId',
            
            'deviceName': 'deviceName',
            
            'hasChildren': 'hasChildren',
            
            'hasParent': 'hasParent',
            
            'persistDateTime': 'persistDateTime',
            
            'siteName': 'siteName',
            
            'auditParentId': 'auditParentId',
            
            'auditId': 'auditId'
            
        }       

        
        #This field is deprecated. Use &#39;id&#39; instead.
        
        self.instanceUuid = None # str
        
        
        self.severity = None # str
        
        
        self.tag = None # str
        
        
        self.applicationName = None # str
        
        
        self.auditParameters = None # dict
        
        
        self.deviceIP = None # str
        
        
        self.auditDescription = None # str
        
        
        self.auditRequestor = None # str
        
        
        self.createdDateTime = None # date-time
        
        
        self.derivedParentId = None # str
        
        
        self.deviceName = None # str
        
        
        self.hasChildren = None # bool
        
        
        self.hasParent = None # bool
        
        
        self.persistDateTime = None # date-time
        
        
        self.siteName = None # str
        
        
        self.auditParentId = None # str
        
        
        self.auditId = None # str
